<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
<xsl:output method="text"/>
<xsl:param name="UID"/>  
<xsl:param name="TOKEN"/>  
<xsl:param name="PRIVATE"/>

<xsl:variable name="RESPONSE" select="'Response'"/>
<xsl:variable name="PARAMS" select="'Params'"/>
<xsl:variable name="STRING" select="'string'"/>
<xsl:variable name="STRUCT" select="'struct'"/>
<xsl:variable name="ARRAY" select="'array'"/>
<xsl:variable name="IMG" select="'img'"/>
<xsl:variable name="PAGE" select="/data/Request/Params/number[@name='page']"/>
<xsl:variable name="PAGE_SIZE" select="/data/Request/Params/number[@name='pageSize']"/>


<xsl:include href="errors.xsl"/>

<xsl:template match="/">
 <xsl:apply-templates select="/data/response_friends_get"/>
 <xsl:apply-templates select="/data/error"/>
 <xsl:apply-templates select="/data/info"/>
</xsl:template>

<xsl:template match="response_friends_get">

    <xsl:element name="{$RESPONSE}">
        <xsl:attribute name="class">friends</xsl:attribute>
        <xsl:attribute name="function">getListFriends</xsl:attribute>
        <xsl:element name="{$PARAMS}">

            <xsl:attribute name="id">
                <xsl:if test="/data/Request/Params/@id">
                    <xsl:value-of select="/data/Request/Params/@id"/>
                </xsl:if>
                <xsl:if test="not(/data/Request/Params/@id)">
                    <xsl:text>mm</xsl:text>
                    <xsl:value-of select="$UID"/>
                </xsl:if>
            </xsl:attribute>

            <xsl:element name="{$ARRAY}">
                <xsl:variable name="quantity" select="count(user)"/>

                <xsl:attribute name="name">ContactList</xsl:attribute>
                <xsl:attribute name="page">
                        <xsl:value-of select="/data/Request/Params/number[@name='page']"/> 
                </xsl:attribute>

                <xsl:attribute name="pageSize">
                        <xsl:value-of select="/data/Request/Params/number[@name='pageSize']"/> 
                </xsl:attribute>

                <xsl:attribute name="quantity">
                        <xsl:value-of select="number($quantity)"/>
                </xsl:attribute>

                <xsl:choose>
                    <xsl:when test="string-length($PAGE) != 0 and string-length($PAGE_SIZE) != 0">
                    <xsl:attribute name="quantity">
                            <xsl:value-of select="count(user[position()&lt;(number($PAGE_SIZE)+1)])"/>
                    </xsl:attribute>
                    <xsl:for-each select="user[position()&lt;(number($PAGE_SIZE)+1)]">
                        <xsl:apply-templates select="."/>
                    </xsl:for-each>
                    </xsl:when>
                    <xsl:otherwise>
                    <xsl:attribute name="quantity">
                            <xsl:value-of select="count(user)"/>
                    </xsl:attribute>
                    <xsl:for-each select="user">
                        <xsl:apply-templates select="."/>
                    </xsl:for-each>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:element> 
        </xsl:element> 
    </xsl:element> 
</xsl:template>

<xsl:template match="user">
    <xsl:element name="{$STRUCT}">
        <xsl:attribute name="name">Contact</xsl:attribute>
        <xsl:attribute name="id">
            <xsl:text>mm</xsl:text>
        <xsl:value-of select="uid"/>
        </xsl:attribute>

        <xsl:element name="{$STRING}">
           <xsl:attribute name="name">FirstName</xsl:attribute>
           <xsl:value-of select="first_name"/>
        </xsl:element>

        <xsl:element name="{$STRING}">
            <xsl:attribute name="name">LastName</xsl:attribute>
            <xsl:value-of select="last_name"/>
        </xsl:element>

        <xsl:element name="{$STRING}">
            <xsl:attribute name="name">NickName</xsl:attribute>
           <xsl:value-of select="nick"/>
        </xsl:element>

        <xsl:element name="{$STRING}">
            <xsl:attribute name="name">FriendStatus</xsl:attribute>
            <xsl:value-of select="is_online"/>
        </xsl:element>

        <xsl:element name="{$IMG}">
            <xsl:attribute name="name">Img</xsl:attribute>
            <xsl:value-of select="pic"/>
        </xsl:element>
    </xsl:element>
</xsl:template>
</xsl:stylesheet>
