<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
<xsl:output method="text"/>
<xsl:param name="UID"/>  
<xsl:param name="TOKEN"/>  
<xsl:param name="PRIVATE"/>

<xsl:variable name="RESPONSE" select="'Response'"/>
<xsl:variable name="PARAMS" select="'Params'"/>
<xsl:variable name="STRING" select="'string'"/>
<xsl:variable name="NUMBER" select="'number'"/>
<xsl:variable name="STRUCT" select="'struct'"/>
<xsl:variable name="ARRAY" select="'array'"/>
<xsl:variable name="PAGE" select="/data/Request/Params/number[@name='page']"/>
<xsl:variable name="PAGE_SIZE" select="/data/Request/Params/number[@name='pageSize']"/>

<xsl:include href="errors.xsl"/>

<xsl:template match="/">
 <xsl:apply-templates select="/data/response_photos_get"/>
 <xsl:apply-templates select="/data/error"/>
 <xsl:apply-templates select="/data/info"/>
</xsl:template>

<xsl:template match="response_photos_get">

    <xsl:element name="{$RESPONSE}">
        <xsl:attribute name="class">photos</xsl:attribute>
        <xsl:attribute name="function">getListPhotos</xsl:attribute>
        <xsl:element name="{$PARAMS}">

            <xsl:element name="{$ARRAY}">
                <xsl:variable name="quantity" select="count(photo)"/>

                <xsl:attribute name="name">photosList</xsl:attribute>
                <xsl:attribute name="page">
                        <xsl:value-of select="/data/Request/Params/number[@name='page']"/> 
                </xsl:attribute>

                <xsl:attribute name="pageSize">
                        <xsl:value-of select="/data/Request/Params/number[@name='pageSize']"/> 
                </xsl:attribute>

                <xsl:attribute name="ownerId">
                <xsl:choose>
            	    <xsl:when test="string-length(photo/owner) != 0">
                	<xsl:text>mm</xsl:text>
                	<xsl:value-of select="photo/owner"/>
                    </xsl:when>
                    <xsl:otherwise>
                	<xsl:value-of select="/data/Request/Params/@id"/>
                    </xsl:otherwise>
                </xsl:choose>
                </xsl:attribute>

                <xsl:attribute name="albumId">
                <xsl:choose>
                    <xsl:when test="string-length(photo/aid) != 0">
                	<xsl:text>mm</xsl:text>
                	<xsl:value-of select="photo/aid"/>
            	    </xsl:when>
            	    <xsl:otherwise>
            		<xsl:value-of select="/data/Request/Params/string[@name='albumId']"/>
            	    </xsl:otherwise>
            	</xsl:choose>
                </xsl:attribute>

                <xsl:choose>
                    <xsl:when test="string-length($PAGE) != 0 and string-length($PAGE_SIZE) != 0">
                    <xsl:attribute name="quantity">
                            <xsl:value-of select="count(photo[position()&lt;(number($PAGE) * number($PAGE_SIZE) + 1) and position() &gt; ((number($PAGE) - 1) * number($PAGE_SIZE))])"/>
                    </xsl:attribute>
                    <xsl:for-each select="photo[position()&lt;(number($PAGE) * number($PAGE_SIZE) + 1) and position() &gt; ((number($PAGE) - 1) * number($PAGE_SIZE))]">
                        <xsl:apply-templates select="."/>
                    </xsl:for-each>
                    </xsl:when>
                    <xsl:otherwise>
                    <xsl:attribute name="quantity">
                            <xsl:value-of select="count(photo)"/>
                    </xsl:attribute>
                    <xsl:for-each select="photo">
                        <xsl:apply-templates select="."/>
                    </xsl:for-each>
                    </xsl:otherwise>
                </xsl:choose>


            </xsl:element> 

        </xsl:element> 
    </xsl:element> 
</xsl:template>

<xsl:template match="photo">
    <xsl:element name="{$STRUCT}">
	<xsl:attribute name="name">photo</xsl:attribute>
        <xsl:attribute name="id">
            <xsl:text>mm</xsl:text>
        <xsl:value-of select="pid"/>
        </xsl:attribute>

        <xsl:element name="{$STRING}">
           <xsl:attribute name="name">urlSmall</xsl:attribute>
           <xsl:value-of select="src"/>
        </xsl:element>

        <xsl:element name="{$STRING}">
            <xsl:attribute name="name">urlBig</xsl:attribute>
            <xsl:value-of select="src"/>
        </xsl:element>

        <xsl:if test="src_big">
            <xsl:element name="{$STRING}">
                <xsl:attribute name="name">urlOrig</xsl:attribute>
                <xsl:value-of select="src_big"/>
            </xsl:element>
        </xsl:if>

        <xsl:element name="{$NUMBER}">
            <xsl:attribute name="name">created</xsl:attribute>
            <xsl:value-of select="created"/>
        </xsl:element>
    </xsl:element>
</xsl:template>

</xsl:stylesheet>
